@@ -64,7 +64,7 @@ class ServletRequestWrapper extends HttpServletRequestWrapper
 	private static final List<String> FORWARD_ATTRIBUTES = Arrays.asList(FORWARD_CONTEXT_PATH,
         FORWARD_MAPPING, FORWARD_PATH_INFO, FORWARD_QUERY_STRING, FORWARD_REQUEST_URI, FORWARD_SERVLET_PATH);
 
-	private static final List<String> INCLUDE_ATTRIBUTES = Arrays.asList(INCLUDE_CONTEXT_PATH, 
+	private static final List<String> INCLUDE_ATTRIBUTES = Arrays.asList(INCLUDE_CONTEXT_PATH,
         INCLUDE_MAPPING, INCLUDE_PATH_INFO, INCLUDE_QUERY_STRING, INCLUDE_REQUEST_URI, INCLUDE_SERVLET_PATH);
 
 	private final DispatcherType type;
@@ -122,7 +122,7 @@ class ServletRequestWrapper extends HttpServletRequestWrapper
             else if (FORWARD_ATTRIBUTES.contains(name) ) {
                 return super.getAttribute(name);
             }
-        } 
+        }
         else if (isForwardingDispatcher() && !this.requestInfo.nameMatch)
         {
             // The jakarta.servlet.forward.* attributes refer to the information of the *original* request,
@@ -382,7 +382,6 @@ class ServletRequestWrapper extends HttpServletRequestWrapper
     }
 
     @Override
-    @SuppressWarnings({ "unchecked", "rawtypes" })
     public Collection<Part> getParts() throws IOException, ServletException {
         throw new ServletException("No Multipart-Support available");
     }
