@@ -70,6 +70,7 @@ import org.apache.felix.http.base.internal.whiteboard.tracker.ResourceTracker;
 import org.apache.felix.http.base.internal.whiteboard.tracker.ServletContextHelperTracker;
 import org.apache.felix.http.base.internal.whiteboard.tracker.ServletTracker;
 import org.jetbrains.annotations.NotNull;
+import org.jetbrains.annotations.Nullable;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.Constants;
 import org.osgi.framework.Filter;
@@ -118,6 +119,7 @@ public final class WhiteboardManager
     private final FailureStateHandler failureStateHandler = new FailureStateHandler();
 
     private volatile ServletContext webContext;
+    private volatile Map<String, Object> attributesForSharedContext = new HashMap<>();
 
     /**
      * Create a new whiteboard http manager
@@ -139,6 +141,7 @@ public final class WhiteboardManager
     /**
      * Start the whiteboard manager
      * @param containerContext The servlet context
+     * @param httpServiceProps Service registration properties
      */
     public void start(final ServletContext containerContext, @NotNull final Dictionary<String, Object> httpServiceProps)
     {
@@ -203,6 +206,7 @@ public final class WhiteboardManager
         this.contextMap.clear();
         this.servicesMap.clear();
         this.failureStateHandler.clear();
+        this.attributesForSharedContext.clear();
         this.registry.reset();
     }
 
@@ -366,6 +370,8 @@ public final class WhiteboardManager
                         {
                             handlerList.add(handler);
                             Collections.sort(handlerList);
+                            setAttributes(handler.getSharedContext());
+
                             this.contextMap.put(info.getName(), handlerList);
 
                             // check for deactivate
@@ -402,6 +408,21 @@ public final class WhiteboardManager
         return false;
     }
 
+    /**
+     * Set the stored attributes on the shared servlet context.
+     * @param context the shared servlet context
+     */
+    private void setAttributes(@Nullable ServletContext context) {
+        if (context != null) {
+            attributesForSharedContext.forEach((key, value) -> {
+                if (key != null && value != null) {
+                    SystemLogger.LOGGER.info("WhiteboardManager: Shared context found, setting stored attribute key: '{}', value: '{}'", key, value);
+                    context.setAttribute(key, value);
+                }
+            });
+        }
+    }
+
     /**
      * Remove a servlet context helper
      *
@@ -705,13 +726,7 @@ public final class WhiteboardManager
                 }
                 else
                 {
-                    final ServletHandler servletHandler = new WhiteboardServletHandler(
-                        handler.getContextInfo().getServiceId(),
-                        servletContext,
-                        (ServletInfo)info,
-                        handler.getBundleContext(),
-                        info.getServiceReference().getBundle(),
-                        this.httpBundleContext.getBundle());
+                    final ServletHandler servletHandler = getServletHandler(handler, info, servletContext);
                     handler.getRegistry().registerServlet(servletHandler);
                 }
             }
@@ -784,6 +799,20 @@ public final class WhiteboardManager
         }
     }
 
+    @NotNull
+    private WhiteboardServletHandler getServletHandler(WhiteboardContextHandler handler,
+                                                       WhiteboardServiceInfo<?> info,
+                                                       ExtServletContext servletContext)
+    {
+        return new WhiteboardServletHandler(
+                handler.getContextInfo().getServiceId(),
+                servletContext,
+                (ServletInfo) info,
+                handler.getBundleContext(),
+                info.getServiceReference().getBundle(),
+                this.httpBundleContext.getBundle());
+    }
+
     /**
      * Unregister whiteboard service from the http service
      * @param handler Context handler
@@ -909,8 +938,8 @@ public final class WhiteboardManager
      * @param req The request
      * @param res The response
      * @param dispatcher The dispatcher
-     * @throws IOException
-     * @throws ServletException
+     * @throws IOException If the invocation throws an IOException
+     * @throws ServletException If the invocation throws a ServletException
      */
     public void invokePreprocessors(final HttpServletRequest req,
     		final HttpServletResponse res,
@@ -953,4 +982,14 @@ public final class WhiteboardManager
     {
         this.serviceRuntime.updateChangeCount();
     }
+
+    /**
+     * Stores an attribute in the to be created shared servlet context.
+     * @param key attribute key
+     * @param value attribute value
+     */
+    public void setAttributeSharedServletContext(String key, Object value) {
+        SystemLogger.LOGGER.info("WhiteboardManager: Storing attribute for shared servlet context. Key '{}', value: '{}'", key, value);
+        this.attributesForSharedContext.put(key, value);
+    }
 }
